complex class

Represents a complex number real + imag * i.

Constructors

complex(double real, double imag)
Creates a complex number with the given real and imag parts.
const

Properties

hashCode int
Returns the hash code for this complex number.
no setteroverride
imag double
The imaginary part of the complex number.
final
real double
The real part of the complex number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a string representation of the complex number.
override

Operators

operator ==(Object other) bool
Checks whether two complex numbers are equal.
override