DirentExtension extension

Extension providing dirent.h functionality to the stdc namespace.

on

Methods

closedir(DIR? dirp) int

Available on Stdc, provided by the DirentExtension extension

Closes the directory stream associated with dirp. Returns 0 on success. On failure, returns -1.
opendir(String name) DIR?

Available on Stdc, provided by the DirentExtension extension

Opens a directory stream corresponding to the directory name, and returns a pointer to the directory stream. On error, returns null.
readdir(DIR? dirp) dirent?

Available on Stdc, provided by the DirentExtension extension

Returns a pointer to a dirent representing the next directory entry in the directory stream pointed to by dirp. Returns null on reaching the end of the directory stream or if an error occurred.
rewinddir(DIR? dirp) → void

Available on Stdc, provided by the DirentExtension extension

Resets the position of the directory stream dirp to the beginning of the directory.