rewinddir method
Resets the position of the directory stream dirp to the beginning of the directory.
Implementation
void rewinddir(DIR? dirp) {
if (dirp == null || !dirp._isOpen) return;
dirp._iterator = ioOpendir(dirp._path);
}
Resets the position of the directory stream dirp to the beginning of the directory.
void rewinddir(DIR? dirp) {
if (dirp == null || !dirp._isOpen) return;
dirp._iterator = ioOpendir(dirp._path);
}