RTLD_GLOBAL property
int
get
RTLD_GLOBAL
All symbols are available for relocation processing of other modules.
Implementation
int get RTLD_GLOBAL => 256;
All symbols are available for relocation processing of other modules.
int get RTLD_GLOBAL => 256;