StdcFloat extension

Extension on Stdc to provide <float.h> functionality.

Note: Dart only uses IEEE 754 double-precision 64-bit floating-point numbers. To emulate standard C characteristics, FLT_ constants represent common 32-bit float boundaries, while DBL_ constants represent 64-bit bounds.

on

Properties

DBL_DIG int

Available on Stdc, provided by the StdcFloat extension

Number of decimal digits of precision for a double.
no setter
DBL_EPSILON double

Available on Stdc, provided by the StdcFloat extension

Difference between 1 and the least value greater than 1 that is representable.
no setter
DBL_MAX double

Available on Stdc, provided by the StdcFloat extension

Maximum representable finite double-precision number.
no setter
DBL_MIN double

Available on Stdc, provided by the StdcFloat extension

Minimum normalized positive double-precision number.
no setter
FLT_DIG int

Available on Stdc, provided by the StdcFloat extension

Number of decimal digits of precision for a float.
no setter
FLT_EPSILON double

Available on Stdc, provided by the StdcFloat extension

Difference between 1 and the least value greater than 1 that is representable.
no setter
FLT_MAX double

Available on Stdc, provided by the StdcFloat extension

Maximum representable finite floating-point number.
no setter
FLT_MIN double

Available on Stdc, provided by the StdcFloat extension

Minimum normalized positive floating-point number.
no setter
FLT_RADIX int

Available on Stdc, provided by the StdcFloat extension

Radix of exponent representation.
no setter