StdcFnmatch extension

Extension providing <fnmatch.h> functionality.

on

Properties

FNM_NOESCAPE int

Available on Stdc, provided by the StdcFnmatch extension

Backslash is ordinary character.
no setter
FNM_NOMATCH int

Available on Stdc, provided by the StdcFnmatch extension

Match failed.
no setter
FNM_PATHNAME int

Available on Stdc, provided by the StdcFnmatch extension

Slash in string only matches slash in pattern.
no setter
FNM_PERIOD int

Available on Stdc, provided by the StdcFnmatch extension

Leading period in string must be exactly matched by period in pattern.
no setter

Methods

fnmatch(String pattern, String string, int flags) int

Available on Stdc, provided by the StdcFnmatch extension

Matches string against the shell wildcard pattern. Returns 0 if string matches pattern, FNM_NOMATCH if there is no match, or another non-zero value if there is an error.