optopt property

int get optopt

When getopt encounters an unknown option character or an option with a missing required argument, it stores that option character in this variable.

Implementation

int get optopt => _optopt;
set optopt (int value)

Implementation

set optopt(int value) => _optopt = value;