StdcGlob extension

Extension providing <glob.h> functionality.

on

Properties

GLOB_ABORTED int

Available on Stdc, provided by the StdcGlob extension

Read error.
no setter
GLOB_APPEND int

Available on Stdc, provided by the StdcGlob extension

Append to the results of a previous call to glob().
no setter
GLOB_DOOFFS int

Available on Stdc, provided by the StdcGlob extension

Insert gl_offs initial null pointers into the list of pathnames.
no setter
GLOB_ERR int

Available on Stdc, provided by the StdcGlob extension

Append to the results of a previous call.
no setter
GLOB_MARK int

Available on Stdc, provided by the StdcGlob extension

Append a slash to each path which corresponds to a directory.
no setter
GLOB_NOCHECK int

Available on Stdc, provided by the StdcGlob extension

If no pattern matches, return the original pattern.
no setter
GLOB_NOESCAPE int

Available on Stdc, provided by the StdcGlob extension

Disable backslash escaping.
no setter
GLOB_NOMATCH int

Available on Stdc, provided by the StdcGlob extension

No matches found.
no setter
GLOB_NOSORT int

Available on Stdc, provided by the StdcGlob extension

Do not sort the returned pathnames.
no setter
GLOB_NOSPACE int

Available on Stdc, provided by the StdcGlob extension

Running out of memory.
no setter

Methods

glob(String pattern, int flags, int errfunc(String, int)?, glob_t pglob) int

Available on Stdc, provided by the StdcGlob extension

Find pathnames matching a pattern.
globfree(glob_t pglob) → void

Available on Stdc, provided by the StdcGlob extension

Free memory allocated by glob. (In Dart, this just clears the list).