GLOB_APPEND property
int
get
GLOB_APPEND
Append to the results of a previous call to glob().
Implementation
int get GLOB_APPEND => 32;
Append to the results of a previous call to glob().
int get GLOB_APPEND => 32;