GLOB_DOOFFS property
int
get
GLOB_DOOFFS
Insert gl_offs initial null pointers into the list of pathnames.
Implementation
int get GLOB_DOOFFS => 8;
Insert gl_offs initial null pointers into the list of pathnames.
int get GLOB_DOOFFS => 8;