GLOB_MARK property
int
get
GLOB_MARK
Append a slash to each path which corresponds to a directory.
Implementation
int get GLOB_MARK => 2;
Append a slash to each path which corresponds to a directory.
int get GLOB_MARK => 2;