StdcGrp extension

Extension providing <grp.h> functionality.

on

Methods

getgrgid(int gid) group?

Available on Stdc, provided by the StdcGrp extension

Search the group database for a group ID. Note: This is a structural mock mapped to current process environment.
getgrnam(String name) group?

Available on Stdc, provided by the StdcGrp extension

Search the group database for a name. Note: This is a structural mock mapped to current process environment.