group class
Group structure containing group information.
Constructors
- group()
Properties
- gr_gid ↔ int
-
The numerical group ID
getter/setter pair
-
gr_mem
↔ List<
String> -
Pointer to a null-terminated array of character pointers to member names.
getter/setter pair
- gr_name ↔ String
-
The name of the group
getter/setter pair
- gr_passwd ↔ String
-
The encrypted group password
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited