IntTypesStdc extension

Extension on Stdc to provide <inttypes.h> functionality.

on

Methods

imaxabs(intmax_t j) intmax_t

Available on Stdc, provided by the IntTypesStdc extension

Computes the absolute value of an integer j of maximum width.
imaxdiv(intmax_t numer, intmax_t denom) imaxdiv_t

Available on Stdc, provided by the IntTypesStdc extension

Computes both the quotient and remainder of the division of numer by denom.
strtoimax(String nptr, {int radix = 10}) intmax_t

Available on Stdc, provided by the IntTypesStdc extension

Converts the string nptr to an intmax_t.
strtoumax(String nptr, {int radix = 10}) uintmax_t

Available on Stdc, provided by the IntTypesStdc extension

Converts the string nptr to an uintmax_t.