strtoimax method

intmax_t strtoimax(
  1. String nptr, {
  2. int radix = 10,
})

Converts the string nptr to an intmax_t.

Trims leading whitespace, handles optional signs, stops at the first invalid character, and autodetects the radix (base) if radix is 0 (e.g. 0x for 16).

Implementation

intmax_t strtoimax(String nptr, {int radix = 10}) {
  return _parseWithCStyle(nptr, radix);
}