imaxdiv_t class

Represents the return type of imaxdiv.

Constructors

imaxdiv_t(intmax_t quot, intmax_t rem)
Creates an imaxdiv_t structure with the given quot and rem.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
quot intmax_t
The quotient of the division.
final
rem intmax_t
The remainder of the division.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited