mon_thousands_sep property
The character used to separate groups of digits before the decimal point in monetary values.
Implementation
final String mon_thousands_sep;
The character used to separate groups of digits before the decimal point in monetary values.
final String mon_thousands_sep;