thousands_sep property
The character used to separate groups of digits before the decimal point in non-monetary values.
Implementation
final String thousands_sep;
The character used to separate groups of digits before the decimal point in non-monetary values.
final String thousands_sep;