MathStdc extension
Extension on Stdc to provide <math.h> functionality.
Importing this file attaches standard C mathematical functions
directly to the global stdc instance.
- on
Methods
-
abs(
int x) → int -
Available on Stdc, provided by the MathStdc extension
Computes the absolute value of an integerx. -
acos(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the principal value of the arc cosine ofx. -
asin(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the principal value of the arc sine ofx. -
atan(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the principal value of the arc tangent ofx. -
atan2(
double y, double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the arc tangent ofy/xusing the signs of arguments to determine the correct quadrant. -
cbrt(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the cube root ofx. -
ceil(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the smallest integer value not less thanx. -
cos(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the cosine ofx(measured in radians). -
exp(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the base-e exponential ofx. -
fabs(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the absolute value of a floating-point numberx. -
floor(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the largest integer value not greater thanx. -
fmax(
double x, double y) → double - Returns the larger of its arguments.
-
fmin(
double x, double y) → double - Returns the smaller of its arguments.
-
fmod(
double x, double y) → double -
Available on Stdc, provided by the MathStdc extension
Computes the floating-point remainder ofx/y. -
hypot(
double x, double y) → double -
Available on Stdc, provided by the MathStdc extension
Computes the square root of the sum of the squares ofxandywithout undue overflow or underflow. -
log(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the natural (base-e) logarithm ofx. -
log10(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the base-10 logarithm ofx. -
pow(
double base, double exponent) → double -
Available on Stdc, provided by the MathStdc extension
Computesbaseraised to the powerexponent. -
round(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Roundsxto the nearest integer value, rounding halfway cases away from zero. -
sin(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the sine ofx(measured in radians). -
sqrt(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the non-negative square root ofx. -
tan(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Computes the tangent ofx(measured in radians). -
trunc(
double x) → double -
Available on Stdc, provided by the MathStdc extension
Roundsxtoward zero to the nearest integer value.