StdcPwd extension

Extension providing <pwd.h> functionality.

on

Methods

getpwnam(String name) passwd?

Available on Stdc, provided by the StdcPwd extension

Search the user database for a name. Note: This is a structural mock mapped to current process environment.
getpwuid(int uid) passwd?

Available on Stdc, provided by the StdcPwd extension

Search the user database for a user ID. Note: This is a structural mock mapped to current process environment.