ENTRY class

Entry structure for hash table search.

Constructors

ENTRY(String key, dynamic data)
Creates a new entry

Properties

data ↔ dynamic
Data associated with the key
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String
Key for the entry
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited