SetjmpExtension extension
Extension providing setjmp.h functionality to the stdc namespace.
- on
Methods
-
longjmp(
jmp_buf env, int val) → Never -
Available on Stdc, provided by the SetjmpExtension extension
Restores the environment saved by the most recent invocation ofsetjmpin the same thread, with the corresponding jmp_buf argument. -
setjmp(
jmp_buf env, void body()) → int -
Available on Stdc, provided by the SetjmpExtension extension
Dart-specific adaptation of C'ssetjmp.