longjmp method

Never longjmp(
  1. jmp_buf env,
  2. int val
)

Restores the environment saved by the most recent invocation of setjmp in the same thread, with the corresponding jmp_buf argument.

Does not return. Instead, it unwinds the stack to the matching setjmp call.

Implementation

Never longjmp(jmp_buf env, int val) {
  throw LongJmpException(env, val);
}