stdalign library

<stdalign.h> implementation for stdc

Dart does not allow manual memory alignment control like C (alignas, alignof). This file is provided for standard library completeness.

Classes

alignas
A stub class to represent an alignment annotation structurally.