alignas class

A stub class to represent an alignment annotation structurally.

Constructors

alignas(int alignment)
Creates an alignment annotation.
const

Properties

alignment int
The alignment boundary in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited