va_list class

Represents a C va_list in Dart.

Since Dart does not have raw memory pointers for stack arguments, va_list acts as an iterator over a List<dynamic>.

Constructors

va_list([List? args])
Initializes a va_list with the given arguments.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

internalRevert() → void
Internal method to revert the last va_arg operation. Used by vsprintf to handle invalid format specifiers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited