StdboolExtensions extension

Provides quality-of-life computations on booleans. Note: All non-standard derived utility methods begin with an Uppercase letter to cleanly distinguish them from standard APIs.

on

Methods

Toggle() bool

Available on bool, provided by the StdboolExtensions extension

Toggles the boolean value and returns the new value.
ToInt() int

Available on bool, provided by the StdboolExtensions extension

Converts the boolean to an integer (1 for true, 0 for false), matching C behavior.