stdc library
A unified entrypoint for the stdc library.
You can import this to get access to all available headers at once,
or you can import specific headers like import 'package:stdc/math.dart';
for a more authentic C experience.
Classes
Extension Types
- Int16
- Strict 16-bit signed integer extension type.
- Int32
- Strict 32-bit signed integer extension type.
- Int64
- Strict 64-bit signed integer extension type.
- Int8
- Strict 8-bit signed integer extension type.
- Uint16
- Strict 16-bit unsigned integer extension type.
- Uint32
- Strict 32-bit unsigned integer extension type.
- Uint64
- Strict 64-bit unsigned integer extension type.
- Uint8
- Strict 8-bit unsigned integer extension type.
Extensions
- ComplexStdc on Stdc
- Standard complex math operations.
- CtypeStdc on Stdc
-
Extension on Stdc to provide
<ctype.h>functionality. - IntTypesStdc on Stdc
-
Extension on Stdc to provide
<inttypes.h>functionality. - LocaleStdc on Stdc
-
Extension on Stdc to provide
<locale.h>functionality. - MathStdc on Stdc
-
Extension on Stdc to provide
<math.h>functionality. - StdboolExtensions on bool
- Provides quality-of-life computations on booleans. Note: All non-standard derived utility methods begin with an Uppercase letter to cleanly distinguish them from standard APIs.
- StdboolStdc on Stdc
-
Provides boolean constants under the
stdcnamespace. - StdcAssert on Stdc
-
Extension on Stdc to provide
<assert.h>functionality. - StdcErrno on Stdc
-
Extension on Stdc to provide
<errno.h>functionality. - StdcFloat on Stdc
-
Extension on Stdc to provide
<float.h>functionality. - StdcLimits on Stdc
-
Extension on Stdc to provide
<limits.h>functionality. - StdcSignal on Stdc
-
<signal.h>standard signal handling extensions forstdc. - StdcStdarg on Stdc
-
<stdarg.h>standard variadic argument extensions forstdc. - StdcStdio on Stdc
-
<stdio.h>standard I/O extensions forstdc. - StdcStdlib on Stdc
-
<stdlib.h>standard library extensions forstdc. - StdcTime on Stdc
-
<time.h>standard time extensions forstdc. - StddefStdc on Stdc
-
Provides standard
stddefdefinitions under thestdcnamespace. - StdintStdc on Stdc
-
Extension to provide related constants under the
stdcnamespace. - StringStdc on Stdc
-
Extension on Stdc to provide
<string.h>functionality. - UCharStdc on Stdc
-
Extension on Stdc to provide
<uchar.h>functionality. - WcharStdc on Stdc
-
Extension on Stdc to provide
<wchar.h>functionality. - WctypeStdc on Stdc
-
Extension on Stdc to provide
<wctype.h>functionality.
Typedefs
- char16_t = int
- 16-bit character type used for UTF-16 encoding.
- char32_t = int
- 32-bit character type used for UTF-32 encoding.
- double_complex = complex
-
Alias for complex mapping to C's
double complex. - float_complex = complex
-
Alias for complex mapping to C's
float complex. - int16_t = int
- 16-bit signed integer type.
- int32_t = int
- 32-bit signed integer type.
- int64_t = int
- 64-bit signed integer type.
- int8_t = int
- 8-bit signed integer type.
- intmax_t = int
- Maximum-width signed integer type.
- intptr_t = int
- Integer type capable of holding a pointer.
- ptrdiff_t = int
- Signed integral type of the result of subtracting two pointers.
- sighandler_t = void Function(int)
- Type for a signal handler function.
- size_t = int
- Unsigned integral type of the result of the sizeof operator.
- stdbool = bool
-
Defines
stdboolas a typedef to Dart'sbool. - uint16_t = int
- 16-bit unsigned integer type.
- uint32_t = int
- 32-bit unsigned integer type.
- uint64_t = int
- 64-bit unsigned integer type.
- uint8_t = int
- 8-bit unsigned integer type.
- uintmax_t = int
- Maximum-width unsigned integer type.
- uintptr_t = int
- Unsigned integer type capable of holding a pointer.
- wchar_t = int
- Wide character type (maps to a Unicode Rune).
- wctrans_t = int
- Wide character mapping type.
- wctype_t = int
- Wide character classification type.
- wint_t = int
- Wide integer type.