stddef library

<stddef.h> implementation for stdc

Contains standard type definitions.

Extensions

StddefStdc on Stdc
Provides standard stddef definitions under the stdc namespace.

Typedefs

ptrdiff_t = int
Signed integral type of the result of subtracting two pointers.
size_t = int
Unsigned integral type of the result of the sizeof operator.