ptrdiff_t typedef
ptrdiff_t = int
Signed integral type of the result of subtracting two pointers.
Implementation
typedef ptrdiff_t = int;
Signed integral type of the result of subtracting two pointers.
typedef ptrdiff_t = int;