rewind method
Sets the file position of the stream to the beginning of the file.
Implementation
void rewind(FILE stream) {
fseek(stream, 0, SEEK_SET);
}
Sets the file position of the stream to the beginning of the file.
void rewind(FILE stream) {
fseek(stream, 0, SEEK_SET);
}