exit method
Terminates the calling process normally with the given exit code.
Throws UnsupportedError on platforms without process exit support (e.g., Web).
Implementation
void exit(int code) {
stdlibExit(code);
}
Terminates the calling process normally with the given exit code.
Throws UnsupportedError on platforms without process exit support (e.g., Web).
void exit(int code) {
stdlibExit(code);
}