getenv method

String? getenv(
  1. String name
)

Gets an environment variable by name. Returns null if the variable is not found or if the platform does not support environment variables (e.g., Web).

Implementation

String? getenv(String name) {
  return stdlibGetenv(name);
}