Stat class

Structure to hold file statistics.

Constructors

Stat()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
st_atime int
Access time
getter/setter pair
st_ctime int
Status change time
getter/setter pair
st_mode int
Mode of file
getter/setter pair
st_mtime int
Modification time
getter/setter pair
st_size int
Size of file
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited