sys_time library

<sys/time.h> implementation for stdc

Contains standard time functions like gettimeofday and timeval structure.

Classes

TimeVal
Represents the C standard struct timeval containing seconds and microseconds.
TimeZone
Represents the C standard struct timezone containing timezone information. Note: The use of the timezone structure is obsolete; the tz argument should normally be specified as NULL.

Extensions

SysTimeStdc on Stdc
<sys/time.h> standard extensions for stdc.