SysTimeStdc extension
<sys/time.h> standard extensions for stdc.
- on
Methods
-
gettimeofday(
TimeVal tv, [TimeZone? tz]) → int -
Available on Stdc, provided by the SysTimeStdc extension
Thegettimeofday()function obtains the current time, expressed as seconds and microseconds since the Epoch, and stores it in theTimeValstructure pointed to bytv.