StdcSyslog extension
Extension providing <syslog.h> functionality.
- on
Properties
- LOG_ALERT → int
-
Available on Stdc, provided by the StdcSyslog extension
action must be taken immediatelyno setter - LOG_CONS → int
-
Available on Stdc, provided by the StdcSyslog extension
log on the console if errors in sendingno setter - LOG_CRIT → int
-
Available on Stdc, provided by the StdcSyslog extension
critical conditionsno setter - LOG_DEBUG → int
-
Available on Stdc, provided by the StdcSyslog extension
debug-level messagesno setter - LOG_EMERG → int
-
Available on Stdc, provided by the StdcSyslog extension
system is unusableno setter - LOG_ERR → int
-
Available on Stdc, provided by the StdcSyslog extension
error conditionsno setter - LOG_INFO → int
-
Available on Stdc, provided by the StdcSyslog extension
informationalno setter - LOG_NDELAY → int
-
Available on Stdc, provided by the StdcSyslog extension
don't delay openno setter - LOG_NOTICE → int
-
Available on Stdc, provided by the StdcSyslog extension
normal but significant conditionno setter - LOG_NOWAIT → int
-
Available on Stdc, provided by the StdcSyslog extension
don't wait for console forks: DEPRECATEDno setter - LOG_ODELAY → int
-
Available on Stdc, provided by the StdcSyslog extension
delay open until first syslog() (default)no setter - LOG_PERROR → int
-
Available on Stdc, provided by the StdcSyslog extension
log to stderr as wellno setter - LOG_PID → int
-
Available on Stdc, provided by the StdcSyslog extension
log the pid with each messageno setter - LOG_USER → int
-
Available on Stdc, provided by the StdcSyslog extension
random user-level messagesno setter - LOG_WARNING → int
-
Available on Stdc, provided by the StdcSyslog extension
warning conditionsno setter
Methods
-
closelog(
) → void -
Available on Stdc, provided by the StdcSyslog extension
Closes the file descriptor being used to write to the system logger. -
LOG_MASK(
int pri) → int -
Available on Stdc, provided by the StdcSyslog extension
Creates a mask for a single priority. -
LOG_UPTO(
int pri) → int -
Available on Stdc, provided by the StdcSyslog extension
Creates a mask for all priorities up to and includingpri. -
openlog(
String ident, int logopt, int facility) → void -
Available on Stdc, provided by the StdcSyslog extension
Opens a connection to the system logger for a program. -
setlogmask(
int maskpri) → int -
Available on Stdc, provided by the StdcSyslog extension
Sets the logmask and returns the previous mask. -
syslog(
int priority, String message) → void -
Available on Stdc, provided by the StdcSyslog extension
Generates a log message.