closelog method
void
closelog()
Closes the file descriptor being used to write to the system logger.
Implementation
void closelog() {
_ident = null;
}
Closes the file descriptor being used to write to the system logger.
void closelog() {
_ident = null;
}