termios class
POSIX terminal I/O structure
Constructors
- termios()
Properties
- c_cflag ↔ int
-
control modes
getter/setter pair
- c_iflag ↔ int
-
input modes
getter/setter pair
- c_lflag ↔ int
-
local modes
getter/setter pair
- c_oflag ↔ int
-
output modes
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited