StdcTime extension
<time.h> standard time extensions for stdc.
- on
Methods
-
asctime(
Tm timeptr) → String -
Available on Stdc, provided by the StdcTime extension
Converts a Tm structure to a string in the format "Www Mmm dd hh:mm:ss yyyy\n". -
clock(
) → int - Returns the processor time used by the program since it started. The returned value is expressed in clock ticks (milliseconds here).
-
ctime(
int timeValue) → String -
Available on Stdc, provided by the StdcTime extension
Converts atime_tvalue to a string in the format "Www Mmm dd hh:mm:ss yyyy\n". -
difftime(
int time1, int time0) → double -
Available on Stdc, provided by the StdcTime extension
Returns the difference in seconds between twotime_tvalues. -
gmtime(
int timeValue) → Tm -
Available on Stdc, provided by the StdcTime extension
Converts a Unix timestamp (time_t) to a UTC Tm structure. -
localtime(
int timeValue) → Tm -
Available on Stdc, provided by the StdcTime extension
Converts a Unix timestamp (time_t) to a local Tm structure. -
mktime(
Tm timeptr) → int -
Available on Stdc, provided by the StdcTime extension
Converts a local Tm structure to a Unix timestamp (time_t). This also normalizes the values intimeptr. -
strftime(
String format, Tm timeptr) → String -
Available on Stdc, provided by the StdcTime extension
Formats time according to theformatstring andtimeptrstructure. -
time(
) → int - Returns the current calendar time as a Unix timestamp (seconds since epoch).