Tm class
Represents the C standard struct tm containing broken-down time.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tm_hour ↔ int
-
Hours since midnight
0, 23getter/setter pair - tm_isdst ↔ int
-
Daylight Saving Time flag (-1, 0, or 1)
getter/setter pair
- tm_mday ↔ int
-
Day of the month
1, 31getter/setter pair - tm_min ↔ int
-
Minutes after the hour
0, 59getter/setter pair - tm_mon ↔ int
-
Months since January
0, 11getter/setter pair - tm_sec ↔ int
-
Seconds after the minute
0, 60getter/setter pair - tm_wday ↔ int
-
Days since Sunday
0, 6getter/setter pair - tm_yday ↔ int
-
Days since January 1
0, 365getter/setter pair - tm_year ↔ int
-
Years since 1900
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDateTime(
{bool isUtc = false}) → DateTime - Converts this Tm back into a Dart DateTime.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromDateTime(
DateTime dt) → Tm - Creates a Tm from a Dart DateTime.