WcharStdc extension

Extension on Stdc to provide <wchar.h> functionality.

on

Properties

WCHAR_MAX int

Available on Stdc, provided by the WcharStdc extension

Maximum value for a wchar_t (Maximum Unicode Code Point).
no setter
WCHAR_MIN int

Available on Stdc, provided by the WcharStdc extension

Minimum value for a wchar_t.
no setter
WEOF int

Available on Stdc, provided by the WcharStdc extension

Wide end-of-file indicator.
no setter

Methods

wcscat(List<wchar_t> dest, List<wchar_t> src) List<wchar_t>

Available on Stdc, provided by the WcharStdc extension

Appends the wide string src to the end of the wide string dest.
wcschr(List<wchar_t> wcs, wchar_t wc) int

Available on Stdc, provided by the WcharStdc extension

Finds the first occurrence of the wide character wc in the wide string wcs.
wcscmp(List<wchar_t> s1, List<wchar_t> s2) int

Available on Stdc, provided by the WcharStdc extension

Compares the wide string s1 to the wide string s2. Returns 0 if they are equal, a negative value if s1 is less than s2, and a positive value if s1 is greater than s2.
wcscpy(List<wchar_t> dest, List<wchar_t> src) List<wchar_t>

Available on Stdc, provided by the WcharStdc extension

Copies the wide string src into dest.
wcslen(List<wchar_t> wcs) int

Available on Stdc, provided by the WcharStdc extension

Computes the length of the wide string wcs.
wcsstr(List<wchar_t> haystack, List<wchar_t> needle) int

Available on Stdc, provided by the WcharStdc extension

Finds the first occurrence of the wide substring needle in the wide string haystack.