wcscat method
Appends the wide string src to the end of the wide string dest.
Returns the concatenated wide string.
Implementation
List<wchar_t> wcscat(List<wchar_t> dest, List<wchar_t> src) {
return List<wchar_t>.from(dest)..addAll(src);
}
Appends the wide string src to the end of the wide string dest.
Returns the concatenated wide string.
List<wchar_t> wcscat(List<wchar_t> dest, List<wchar_t> src) {
return List<wchar_t>.from(dest)..addAll(src);
}