wcscpy method
Copies the wide string src into dest.
Because Dart lists can be passed by reference, this returns a new copied List to avoid unexpected shared state.
Implementation
List<wchar_t> wcscpy(List<wchar_t> dest, List<wchar_t> src) {
return List<wchar_t>.from(src);
}