WctypeStdc extension

Extension on Stdc to provide <wctype.h> functionality.

These functions accept a wint_t (Rune integer code point) and perform standard C classifications.

on

Methods

iswalnum(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is alphanumeric.
iswalpha(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is alphabetic.
iswblank(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a blank character (space or tab).
iswcntrl(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a control character.
iswdigit(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a decimal digit.
iswgraph(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character has a graphical representation.
iswlower(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a lowercase letter.
iswprint(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is printable.
iswpunct(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a punctuation character.
iswspace(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a white-space character.
iswupper(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is an uppercase letter.
iswxdigit(int wc) bool

Available on Stdc, provided by the WctypeStdc extension

Checks if the wide character is a hexadecimal digit.
towlower(int wc) int

Available on Stdc, provided by the WctypeStdc extension

Converts an uppercase wide character to lowercase.
towupper(int wc) int

Available on Stdc, provided by the WctypeStdc extension

Converts a lowercase wide character to uppercase.