DirentExtension extension
Extension providing dirent.h functionality to the stdc namespace.
- on
Methods
-
closedir(
DIR? dirp) → int -
Available on Stdc, provided by the DirentExtension extension
Closes the directory stream associated withdirp. Returns 0 on success. On failure, returns -1. -
opendir(
String name) → DIR? -
Available on Stdc, provided by the DirentExtension extension
Opens a directory stream corresponding to the directoryname, and returns a pointer to the directory stream. On error, returnsnull. -
readdir(
DIR? dirp) → dirent? -
Available on Stdc, provided by the DirentExtension extension
Returns a pointer to adirentrepresenting the next directory entry in the directory stream pointed to bydirp. Returnsnullon reaching the end of the directory stream or if an error occurred. -
rewinddir(
DIR? dirp) → void -
Available on Stdc, provided by the DirentExtension extension
Resets the position of the directory streamdirpto the beginning of the directory.