dlclose method
Decrements the reference count on the dynamic library handle.
Note: dart:ffi does not currently provide a way to explicitly close a DynamicLibrary.
This function acts as a no-op but returns 0 for success.
Implementation
int dlclose(DynamicLibrary handle) {
_lastError = null;
return 0; // Success
}