Option class
Structure for long options used by getopt_long.
Constructors
Properties
-
flag
→ List<
int> ? -
If not null, specifies a list of 1 element where the value of
valis stored. If null,getopt_longreturnsval.final - has_arg → int
-
One of
no_argument,required_argument, oroptional_argument.final - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the long option.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- val → int
-
The value to return, or to load into the
flagif it's not null.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited