glob_t class
Wrapper class for glob_t structure.
Constructors
- glob_t()
Properties
- gl_offs ↔ int
-
Slots to reserve at the beginning of gl_pathv.
getter/setter pair
- gl_pathc ↔ int
-
Count of paths matched so far.
getter/setter pair
-
gl_pathv
↔ List<
String> -
List of matched pathnames.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited