iso646 library
<iso646.h> implementation for stdc
In C, this header defines macros for alternative operator spellings
(e.g., and for &&, or for ||).
Dart does not support a macro preprocessor or operator overriding in this manner.
This file is provided for standard library completeness and structural porting.