Lconv class
Dart representation of the C struct lconv.
Contains localization-specific numeric and monetary formatting rules.
Constructors
- Lconv({String decimal_point = ".", String thousands_sep = "", String grouping = "", String int_curr_symbol = "", String currency_symbol = "", String mon_decimal_point = "", String mon_thousands_sep = "", String mon_grouping = "", String positive_sign = "", String negative_sign = "", int int_frac_digits = 127, int frac_digits = 127, int p_cs_precedes = 127, int p_sep_by_space = 127, int n_cs_precedes = 127, int n_sep_by_space = 127, int p_sign_posn = 127, int n_sign_posn = 127})
-
Creates a new Lconv structure with default "C" locale values.
const
Properties
- currency_symbol → String
-
The local currency symbol.
final
- decimal_point → String
-
The decimal point character for non-monetary values.
final
- frac_digits → int
-
The number of fractional digits to be displayed in a formatted monetary quantity.
final
- grouping → String
-
A string that indicates the size of each group of digits in non-monetary values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- int_curr_symbol → String
-
The international currency symbol.
final
- int_frac_digits → int
-
The number of fractional digits to be displayed in an internationally formatted monetary quantity.
final
- mon_decimal_point → String
-
The decimal point character for monetary values.
final
- mon_grouping → String
-
A string that indicates the size of each group of digits in monetary values.
final
- mon_thousands_sep → String
-
The character used to separate groups of digits before the decimal point in monetary values.
final
- n_cs_precedes → int
-
Set to 1 or 0 if the currency symbol precedes or succeeds the value for a negative formatted monetary quantity.
final
- n_sep_by_space → int
-
Set to a value indicating the separation of the currency symbol, the sign string, and the value for a negative formatted monetary quantity.
final
- n_sign_posn → int
-
Set to a value indicating the positioning of the negative_sign for a negative formatted monetary quantity.
final
- negative_sign → String
-
The string used to indicate a negative-valued monetary quantity.
final
- p_cs_precedes → int
-
Set to 1 or 0 if the currency symbol precedes or succeeds the value for a non-negative formatted monetary quantity.
final
- p_sep_by_space → int
-
Set to a value indicating the separation of the currency symbol, the sign string, and the value for a non-negative formatted monetary quantity.
final
- p_sign_posn → int
-
Set to a value indicating the positioning of the positive_sign for a non-negative formatted monetary quantity.
final
- positive_sign → String
-
The string used to indicate a non-negative-valued monetary quantity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thousands_sep → String
-
The character used to separate groups of digits before the decimal point in non-monetary values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited