MathStdc extension

Extension on Stdc to provide <math.h> functionality.

Importing this file attaches standard C mathematical functions directly to the global stdc instance.

on

Methods

abs(int x) int

Available on Stdc, provided by the MathStdc extension

Computes the absolute value of an integer x.
acos(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the principal value of the arc cosine of x.
asin(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the principal value of the arc sine of x.
atan(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the principal value of the arc tangent of x.
atan2(double y, double x) double

Available on Stdc, provided by the MathStdc extension

Computes the arc tangent of y/x using the signs of arguments to determine the correct quadrant.
ceil(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the smallest integer value not less than x.
cos(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the cosine of x (measured in radians).
exp(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the base-e exponential of x.
fabs(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the absolute value of a floating-point number x.
floor(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the largest integer value not greater than x.
log(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the natural (base-e) logarithm of x.
log10(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the base-10 logarithm of x.
pow(double base, double exponent) double

Available on Stdc, provided by the MathStdc extension

Computes base raised to the power exponent.
sin(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the sine of x (measured in radians).
sqrt(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the non-negative square root of x.
tan(double x) double

Available on Stdc, provided by the MathStdc extension

Computes the tangent of x (measured in radians).