addrinfo class
Network host database structure
Constructors
- addrinfo()
Properties
- ai_addr ↔ dynamic
-
Address data
getter/setter pair
- ai_addrlen ↔ int
-
Address length
getter/setter pair
- ai_canonname ↔ String?
-
Canonical name
getter/setter pair
- ai_family ↔ int
-
Family
getter/setter pair
- ai_flags ↔ int
-
AI flags
getter/setter pair
- ai_next ↔ addrinfo?
-
Next item
getter/setter pair
- ai_protocol ↔ int
-
Protocol
getter/setter pair
- ai_socktype ↔ int
-
Socket type
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited