sockaddr_in class

Socket address for internet

Constructors

sockaddr_in()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sin_addr in_addr
Internet address
getter/setter pair
sin_family int
Family
getter/setter pair
sin_port int
Port
getter/setter pair
sin_zero List<int>
Zero padding
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited