passwd class

Password structure containing user information.

Constructors

passwd()

Properties

hashCode int
The hash code for this object.
no setterinherited
pw_dir String
Initial working directory (home directory)
getter/setter pair
pw_gecos String
User's real name (GECOS field)
getter/setter pair
pw_gid int
Numerical group ID
getter/setter pair
pw_name String
User's login name
getter/setter pair
pw_passwd String
The encrypted password (often "x")
getter/setter pair
pw_shell String
Program to use as shell
getter/setter pair
pw_uid int
Numerical user ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited