StdcStdio extension
<stdio.h> standard I/O extensions for stdc.
- on
Properties
- EOF → int
-
Available on Stdc, provided by the StdcStdio extension
End-of-file indicator.no setter - SEEK_CUR → int
-
Available on Stdc, provided by the StdcStdio extension
Seek from current position.no setter - SEEK_END → int
-
Available on Stdc, provided by the StdcStdio extension
Seek from end of file.no setter - SEEK_SET → int
-
Available on Stdc, provided by the StdcStdio extension
Seek from beginning of file.no setter
Methods
-
fclose(
FILE stream) → int - Closes a file stream.
-
feof(
FILE stream) → int -
Available on Stdc, provided by the StdcStdio extension
Tests the end-of-file indicator for the givenstream. Returns a non-zero value if and only if the end-of-file indicator is set. -
fflush(
FILE stream) → int - Flushes a file stream.
-
fopen(
String filename, String mode) → FILE? - Opens a file.
-
fprintf(
FILE stream, String format, [List args = const []]) → int -
Available on Stdc, provided by the StdcStdio extension
Writes formatted output to astream. -
fread(
List< int> ptr, int size, int count, FILE stream) → int -
Available on Stdc, provided by the StdcStdio extension
Reads an array ofcountelements, each one with a size ofsizebytes, from thestream. -
fseek(
FILE stream, int offset, int whence) → int -
Available on Stdc, provided by the StdcStdio extension
Sets the file position of thestreamto the givenoffset. -
ftell(
FILE stream) → int -
Available on Stdc, provided by the StdcStdio extension
Returns the current file position of thestream. -
fwrite(
List< int> ptr, int size, int count, FILE stream) → int -
Available on Stdc, provided by the StdcStdio extension
Writes an array ofcountelements, each one with a size ofsizebytes, to thestream. -
getchar(
) → int - Reads a character from stdin.
-
gets(
) → String? - Reads a line from stdin into a string.
-
perror(
String s) → void - Prints an error message to stderr.
-
printf(
String format, [List args = const []]) → int - Prints formatted output to stdout, returning the number of characters written.
-
putchar(
int char) → int - Writes a character to stdout.
-
puts(
String str) → int - Writes a string to stdout, appended with a newline.
-
remove(
String filename) → int - Deletes a file.
-
rename(
String old_filename, String new_filename) → int - Renames a file.
-
rewind(
FILE stream) → void -
Available on Stdc, provided by the StdcStdio extension
Sets the file position of thestreamto the beginning of the file. -
scanf(
String format) → List -
Available on Stdc, provided by the StdcStdio extension
Reads one line from stdin and parses it according toformat. -
snprintf(
int n, String format, [List args = const []]) → String -
Available on Stdc, provided by the StdcStdio extension
Writes formatted output to a String, truncated to at mostn-1characters. -
sprintf(
String format, [List args = const []]) → String -
Available on Stdc, provided by the StdcStdio extension
Formats arguments into a String according toformat. -
sscanf(
String str, String format) → List -
Available on Stdc, provided by the StdcStdio extension
Parses the stringstraccording toformatand returns matched values. -
tmpfile(
) → FILE? - Creates a temporary binary file.
-
tmpnam(
[List< int> ? str]) → String - Generates a valid temporary file name.
-
vprintf(
String format, va_list arg) → int -
Available on Stdc, provided by the StdcStdio extension
Prints formatted output to stdout using a va_list, returning the character count. -
vsprintf(
String format, va_list arg) → String -
Available on Stdc, provided by the StdcStdio extension
Formats arguments into a String using a va_list.