fwrite method
Writes an array of count elements, each one with a size of size bytes, to the stream.
Implementation
int fwrite(List<int> ptr, int size, int count, FILE stream) {
try {
int bytesToWrite = size * count;
stream._raf.writeFromSync(ptr, 0, bytesToWrite);
return count;
} catch (e) {
return 0;
}
}