Gets an environment variable by name. Returns null if the variable is not found or if the platform does not support environment variables (e.g., Web).
name
null
String? getenv(String name) { return stdlibGetenv(name); }