CString class
Represents a mutable C-style string buffer (char array).
Constructors
- CString.allocate(int size)
-
Allocates a zero-initialized buffer of
sizebytes. - CString.fromString(String s)
-
Allocates a buffer containing the UTF-8 representation of
s, plus a null terminator.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts the buffer up to the first null terminator into a Dart String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → int -
Reads a byte at
index. -
operator []=(
int index, int value) → void -
Writes a byte at
index.