TimeZone class

Represents the C standard struct timezone containing timezone information. Note: The use of the timezone structure is obsolete; the tz argument should normally be specified as NULL.

Constructors

TimeZone({int tz_minuteswest = 0, int tz_dsttime = 0})
Creates a new TimeZone structure.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tz_dsttime int
Type of DST correction
getter/setter pair
tz_minuteswest int
Minutes west of Greenwich
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited