utsname class
Structure describing the system and machine.
Constructors
- utsname()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- machine ↔ String
-
Name of the hardware type on which the system is running.
getter/setter pair
- nodename ↔ String
-
Name of this node on the network.
getter/setter pair
- release ↔ String
-
Current release level of the operating system.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sysname ↔ String
-
Name of the implementation of the operating system.
getter/setter pair
- version ↔ String
-
Current version level of the operating system.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited