StdcSyslog extension

Extension providing <syslog.h> functionality.

on

Properties

LOG_ALERT int

Available on Stdc, provided by the StdcSyslog extension

action must be taken immediately
no setter
LOG_CONS int

Available on Stdc, provided by the StdcSyslog extension

log on the console if errors in sending
no setter
LOG_CRIT int

Available on Stdc, provided by the StdcSyslog extension

critical conditions
no setter
LOG_DEBUG int

Available on Stdc, provided by the StdcSyslog extension

debug-level messages
no setter
LOG_EMERG int

Available on Stdc, provided by the StdcSyslog extension

system is unusable
no setter
LOG_ERR int

Available on Stdc, provided by the StdcSyslog extension

error conditions
no setter
LOG_INFO int

Available on Stdc, provided by the StdcSyslog extension

informational
no setter
LOG_NDELAY int

Available on Stdc, provided by the StdcSyslog extension

don't delay open
no setter
LOG_NOTICE int

Available on Stdc, provided by the StdcSyslog extension

normal but significant condition
no setter
LOG_NOWAIT int

Available on Stdc, provided by the StdcSyslog extension

don't wait for console forks: DEPRECATED
no setter
LOG_ODELAY int

Available on Stdc, provided by the StdcSyslog extension

delay open until first syslog() (default)
no setter
LOG_PERROR int

Available on Stdc, provided by the StdcSyslog extension

log to stderr as well
no setter
LOG_PID int

Available on Stdc, provided by the StdcSyslog extension

log the pid with each message
no setter
LOG_USER int

Available on Stdc, provided by the StdcSyslog extension

random user-level messages
no setter
LOG_WARNING int

Available on Stdc, provided by the StdcSyslog extension

warning conditions
no setter

Methods

closelog() → void

Available on Stdc, provided by the StdcSyslog extension

Closes the file descriptor being used to write to the system logger.
LOG_MASK(int pri) int

Available on Stdc, provided by the StdcSyslog extension

Creates a mask for a single priority.
LOG_UPTO(int pri) int

Available on Stdc, provided by the StdcSyslog extension

Creates a mask for all priorities up to and including pri.
openlog(String ident, int logopt, int facility) → void

Available on Stdc, provided by the StdcSyslog extension

Opens a connection to the system logger for a program.
setlogmask(int maskpri) int

Available on Stdc, provided by the StdcSyslog extension

Sets the logmask and returns the previous mask.
syslog(int priority, String message) → void

Available on Stdc, provided by the StdcSyslog extension

Generates a log message.