StdcTime extension

<time.h> standard time extensions for stdc.

on

Methods

clock() int

Available on Stdc, provided by the StdcTime extension

Returns the processor time used by the program since it started. The returned value is expressed in clock ticks (milliseconds here).
ctime(int timeValue) String

Available on Stdc, provided by the StdcTime extension

Converts a time_t value to a string in the format "Www Mmm dd hh:mm:ss yyyy\n". Note: A simplified approximation for Dart.
difftime(int time1, int time0) double

Available on Stdc, provided by the StdcTime extension

Returns the difference in seconds between two time_t values.
time() int

Available on Stdc, provided by the StdcTime extension

Returns the current calendar time as a Unix timestamp (seconds since epoch).