StdcTime extension
<time.h> standard time extensions for stdc.
- on
Methods
-
clock(
) → int - Returns the processor time used by the program since it started. The returned value is expressed in clock ticks (milliseconds here).
-
ctime(
int timeValue) → String -
Available on Stdc, provided by the StdcTime extension
Converts atime_tvalue to a string in the format "Www Mmm dd hh:mm:ss yyyy\n". Note: A simplified approximation for Dart. -
difftime(
int time1, int time0) → double -
Available on Stdc, provided by the StdcTime extension
Returns the difference in seconds between twotime_tvalues. -
time(
) → int - Returns the current calendar time as a Unix timestamp (seconds since epoch).