clock method
Returns the processor time used by the program since it started. The returned value is expressed in clock ticks (milliseconds here).
Implementation
int clock() {
return _clock.elapsedMilliseconds;
}
Returns the processor time used by the program since it started. The returned value is expressed in clock ticks (milliseconds here).
int clock() {
return _clock.elapsedMilliseconds;
}