Tm class

Represents the C standard struct tm containing broken-down time.

Constructors

Tm({int tm_sec = 0, int tm_min = 0, int tm_hour = 0, int tm_mday = 1, int tm_mon = 0, int tm_year = 0, int tm_wday = 0, int tm_yday = 0, int tm_isdst = -1})
Creates a new Tm structure.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tm_hour int
Hours since midnight 0, 23
getter/setter pair
tm_isdst int
Daylight Saving Time flag (-1, 0, or 1)
getter/setter pair
tm_mday int
Day of the month 1, 31
getter/setter pair
tm_min int
Minutes after the hour 0, 59
getter/setter pair
tm_mon int
Months since January 0, 11
getter/setter pair
tm_sec int
Seconds after the minute 0, 60
getter/setter pair
tm_wday int
Days since Sunday 0, 6
getter/setter pair
tm_yday int
Days since January 1 0, 365
getter/setter pair
tm_year int
Years since 1900
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDateTime({bool isUtc = false}) DateTime
Converts this Tm back into a Dart DateTime.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromDateTime(DateTime dt) Tm
Creates a Tm from a Dart DateTime.