WcharStdc extension
Extension on Stdc to provide <wchar.h> functionality.
- on
Properties
- WCHAR_MAX → int
-
Available on Stdc, provided by the WcharStdc extension
Maximum value for awchar_t(Maximum Unicode Code Point).no setter - WCHAR_MIN → int
-
Available on Stdc, provided by the WcharStdc extension
Minimum value for awchar_t.no setter - WEOF → int
-
Available on Stdc, provided by the WcharStdc extension
Wide end-of-file indicator.no setter
Methods
-
wcscat(
List< wchar_t> dest, List<wchar_t> src) → List<wchar_t> -
Available on Stdc, provided by the WcharStdc extension
Appends the wide stringsrcto the end of the wide stringdest. -
wcschr(
List< wchar_t> wcs, wchar_t wc) → int -
Available on Stdc, provided by the WcharStdc extension
Finds the first occurrence of the wide characterwcin the wide stringwcs. -
wcscmp(
List< wchar_t> s1, List<wchar_t> s2) → int -
Available on Stdc, provided by the WcharStdc extension
Compares the wide strings1to the wide strings2. Returns 0 if they are equal, a negative value ifs1is less thans2, and a positive value ifs1is greater thans2. -
wcscpy(
List< wchar_t> dest, List<wchar_t> src) → List<wchar_t> -
Available on Stdc, provided by the WcharStdc extension
Copies the wide stringsrcintodest. -
wcslen(
List< wchar_t> wcs) → int -
Available on Stdc, provided by the WcharStdc extension
Computes the length of the wide stringwcs. -
wcsstr(
List< wchar_t> haystack, List<wchar_t> needle) → int -
Available on Stdc, provided by the WcharStdc extension
Finds the first occurrence of the wide substringneedlein the wide stringhaystack.